@@ -1,11 +1,11 @@
-from excel2meta_interface.utils import messages, helpers
-
-from inspect import currentframe
+import csv
+import json
 from datetime import datetime
 from glob import glob
+from inspect import currentframe
 from os import path, makedirs
-import json
-import csv
+
+from excel2meta_interface.utils import messages, helpers
 
 
 class JSON2EDCLineageFiles:
@@ -220,7 +220,14 @@ class JSON2EDCLineageFiles:
             to_attribute = source_target_attribute_link["transformation"]["to"]
             # to_attribute has to be in one of the target entities
             result_check, entity, to_attribute_name = self.get_entity_attribute(to_entities, to_attribute)
-            tgt_entity = self.get_entity(entity_uuid=entity)["name"]
+            tgt_entity_uuid = self.get_entity(entity_uuid=entity)
+            if tgt_entity_uuid is None:
+                result = messages.message["target_entity_not_found"]
+                result["info"] = "Could not find entity with uuid >%s< " % (entity)
+                overall_result = result
+                continue
+            else:
+                tgt_entity = tgt_entity_uuid["name"]
             if not result_check:
                 result = messages.message["target_attribute_not_in_target_entities"]
                 result["info"] = "to_attribute >%s< not found in target entities >%s<" % (to_attribute, str(to_entities))
